@@ -63,13 +63,13 @@
 #' a fraction of the axis:
 #' \itemize{
 #' \item{\code{"any"}: the standard deviations can have values from 1\% to 50\% of axes' ranges. For example if the first axis of the PCA ranges from -5 to +5,
-#' then sd values along this axe can range from 0.1 to 5.
+#' then sd values along this axis can range from 0.1 to 5.
 #' }
 #' \item{\code{"narrow"}: the standard deviations are limited between 1\% and 10\% of axes' ranges. For example if the first axis of the PCA ranges from -5 to +5,
-#' then sd values along this axe can range from 0.1 to 1.
+#' then sd values along this axis can range from 0.1 to 1.
 #' }
 #' \item{\code{"wide"}: the standard deviations are limited between 10\% and 50\% of axes' ranges. For example if the first axis of the PCA ranges from -5 to +5,
-#' then sd values along this axe can range from 1 to 5.
+#' then sd values along this axis can range from 1 to 5.
 #' }
 #' }
 #' If a \code{bca} object is provided, the output bca object will contain the new environments coordinates along the provided bca axes.
@@ -86,7 +86,7 @@
 #' \item{\code{suitab.raster.future}: the virtual species distribution, as a Raster object containing the
 #' future environmental suitability}
 #' }
-#' The structure of the virtualspecies object can be seen using str()
+#' The structure of the virtualspecies object can be seen using \code{str()}
 #' 
 #' 
 #' 
@@ -367,6 +367,6 @@ generateSpFromBCA <- function(raster.stack.current, raster.stack.future, rescale
                                  stack.lengths = stack.lengths),
                   suitab.raster.current = suitab.raster.current,
                   suitab.raster.future = suitab.raster.future)
-  class(results) <- append(class(results), "virtualspecies")
+  class(results) <- append("virtualspecies", class(results))
   return(results)
 }
